package common

import "github.com/in-toto/in-toto-golang/in_toto/slsa_provenance/common"

Index

Types

type DigestSet

type DigestSet map[string]string

DigestSet contains a set of digests. It is represented as a map from algorithm name to lowercase hex-encoded value.

type ProvenanceBuilder

type ProvenanceBuilder struct {
	ID string `json:"id"`
}

ProvenanceBuilder idenfifies the entity that executed the build steps.

type ProvenanceMaterial

type ProvenanceMaterial struct {
	URI    string    `json:"uri,omitempty"`
	Digest DigestSet `json:"digest,omitempty"`
}

ProvenanceMaterial defines the materials used to build an artifact.

Source Files

common.go

Version
v0.9.0 (latest)
Published
May 4, 2023
Platform
linux/amd64
Last checked
10 months ago

Tools for package owners.