package v01
import "github.com/in-toto/in-toto-golang/in_toto/slsa_provenance/v0.1"
Index ¶
- Constants
- type ProvenanceComplete
- type ProvenanceMetadata
- type ProvenancePredicate
- type ProvenanceRecipe
Constants ¶
const ( // PredicateSLSAProvenance represents a build provenance for an artifact. PredicateSLSAProvenance = "https://slsa.dev/provenance/v0.1" )
Types ¶
type ProvenanceComplete ¶
type ProvenanceComplete struct {
Arguments bool `json:"arguments"`
Environment bool `json:"environment"`
Materials bool `json:"materials"`
}
ProvenanceComplete indicates wheter the claims in build/recipe are complete. For in depth information refer to the specifictaion: https://github.com/in-toto/attestation/blob/v0.1.0/spec/predicates/provenance.md
type ProvenanceMetadata ¶
type ProvenanceMetadata struct {
// Use pointer to make sure that the abscense of a time is not
// encoded as the Epoch time.
BuildStartedOn *time.Time `json:"buildStartedOn,omitempty"`
BuildFinishedOn *time.Time `json:"buildFinishedOn,omitempty"`
Completeness ProvenanceComplete `json:"completeness"`
Reproducible bool `json:"reproducible"`
}
ProvenanceMetadata contains metadata for the built artifact.
type ProvenancePredicate ¶
type ProvenancePredicate struct {
Builder common.ProvenanceBuilder `json:"builder"`
Recipe ProvenanceRecipe `json:"recipe"`
Metadata *ProvenanceMetadata `json:"metadata,omitempty"`
Materials []common.ProvenanceMaterial `json:"materials,omitempty"`
}
ProvenancePredicate is the provenance predicate definition.
type ProvenanceRecipe ¶
type ProvenanceRecipe struct {
Type string `json:"type"`
// DefinedInMaterial can be sent as the null pointer to indicate that
// the value is not present.
DefinedInMaterial *int `json:"definedInMaterial,omitempty"`
EntryPoint string `json:"entryPoint"`
Arguments interface{} `json:"arguments,omitempty"`
Environment interface{} `json:"environment,omitempty"`
}
ProvenanceRecipe describes the actions performed by the builder.
Source Files ¶
- Version
- v0.9.0 (latest)
- Published
- May 4, 2023
- Platform
- linux/amd64
- Imports
- 2 packages
- Last checked
- 10 months ago –
Tools for package owners.